@@ -15,6 +15,9 @@ def sudo(command):
     """do shell with administrator privileges
     http://developer.apple.com/library/mac/#technotes/tn2065/_index.html"""
     escaped=command.replace('"','\\"')
-    return run("osascript",
-        'do shell script "%s" with administrator privileges' % escaped
-    ).std_out
\ No newline at end of file
+    cmd='do shell script "%s" with administrator privileges' % escaped
+    r=run("osascript",cmd)
+    if r.status_code==0:
+        return r.std_out
+    else:
+        raise Exception(r.std_err)
\ No newline at end of file
